pub struct ScamperPingProbe { /* private fields */ }Expand description
A single ping probe.
Implementations
Sourceimpl ScamperPingProbe
impl ScamperPingProbe
pub fn id(&self) -> u16
pub fn ipid(&self) -> u16
pub fn tx(&self) -> Option<SystemTime>
pub fn flags(&self) -> u32
Sourcepub fn reply(&self, i: u16) -> Option<ScamperPingReply>
pub fn reply(&self, i: u16) -> Option<ScamperPingReply>
Return the reply at index i for this probe.
Sourcepub fn reply_is_from_target(&self, reply: &ScamperPingReply) -> bool
pub fn reply_is_from_target(&self, reply: &ScamperPingReply) -> bool
Check if the given reply is from the target.